Class: Aws::IoTRoboRunner::Client

Inherits:
Seahorse::Client::Base
  • Object
show all
Includes:
ClientStubs
Defined in:
lib/aws-sdk-iotroborunner/client.rb

Overview

An API client for IoTRoboRunner. To construct a client, you need to configure a :region and :credentials.

client = Aws::IoTRoboRunner::Client.new(
  region: region_name,
  credentials: credentials,
  # ...
)

For details on configuring region and credentials see the developer guide.

See #initialize for a full list of supported configuration options.

Class Attribute Summary collapse

API Operations collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ Client

Returns a new instance of Client.

Parameters:

  • options (Hash)

Options Hash (options):

  • :credentials (required, Aws::CredentialProvider) —

    Your AWS credentials. This can be an instance of any one of the following classes:

    • Aws::Credentials - Used for configuring static, non-refreshing credentials.

    • Aws::SharedCredentials - Used for loading static credentials from a shared file, such as ~/.aws/config.

    • Aws::AssumeRoleCredentials - Used when you need to assume a role.

    • Aws::AssumeRoleWebIdentityCredentials - Used when you need to assume a role after providing credentials via the web.

    • Aws::SSOCredentials - Used for loading credentials from AWS SSO using an access token generated from aws login.

    • Aws::ProcessCredentials - Used for loading credentials from a process that outputs to stdout.

    • Aws::InstanceProfileCredentials - Used for loading credentials from an EC2 IMDS on an EC2 instance.

    • Aws::ECSCredentials - Used for loading credentials from instances running in ECS.

    • Aws::CognitoIdentityCredentials - Used for loading credentials from the Cognito Identity service.

    When :credentials are not configured directly, the following locations will be searched for credentials:

    • Aws.config[:credentials]
    • The :access_key_id, :secret_access_key, and :session_token options.
    • ENV, ENV
    • ~/.aws/credentials
    • ~/.aws/config
    • EC2/ECS IMDS instance profile - When used by default, the timeouts are very aggressive. Construct and pass an instance of Aws::InstanceProfileCredentails or Aws::ECSCredentials to enable retries and extended timeouts. Instance profile credential fetching can be disabled by setting ENV to true.
  • :region (required, String) —

    The AWS region to connect to. The configured :region is used to determine the service :endpoint. When not passed, a default :region is searched for in the following locations:

    • Aws.config[:region]
    • ENV['AWS_REGION']
    • ENV['AMAZON_REGION']
    • ENV['AWS_DEFAULT_REGION']
    • ~/.aws/credentials
    • ~/.aws/config
  • :access_key_id (String)
  • :active_endpoint_cache (Boolean) — default: false —

    When set to true, a thread polling for endpoints will be running in the background every 60 secs (default). Defaults to false.

  • :adaptive_retry_wait_to_fill (Boolean) — default: true —

    Used only in adaptive retry mode. When true, the request will sleep until there is sufficent client side capacity to retry the request. When false, the request will raise a RetryCapacityNotAvailableError and will not retry instead of sleeping.

  • :client_side_monitoring (Boolean) — default: false —

    When true, client-side metrics will be collected for all API requests from this client.

  • :client_side_monitoring_client_id (String) — default: "" —

    Allows you to provide an identifier for this client which will be attached to all generated client side metrics. Defaults to an empty string.

  • :client_side_monitoring_host (String) — default: "127.0.0.1" —

    Allows you to specify the DNS hostname or IPv4 or IPv6 address that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_port (Integer) — default: 31000 —

    Required for publishing client metrics. The port that the client side monitoring agent is running on, where client metrics will be published via UDP.

  • :client_side_monitoring_publisher (Aws::ClientSideMonitoring::Publisher) — default: Aws::ClientSideMonitoring::Publisher —

    Allows you to provide a custom client-side monitoring publisher class. By default, will use the Client Side Monitoring Agent Publisher.

  • :convert_params (Boolean) — default: true —

    When true, an attempt is made to coerce request parameters into the required types.

  • :correct_clock_skew (Boolean) — default: true —

    Used only in standard and adaptive retry modes. Specifies whether to apply a clock skew correction and retry requests with skewed client clocks.

  • :defaults_mode (String) — default: "legacy" —

    See DefaultsModeConfiguration for a list of the accepted modes and the configuration defaults that are included.

  • :disable_host_prefix_injection (Boolean) — default: false —

    Set to true to disable SDK automatically adding host prefix to default service endpoint when available.

  • :disable_request_compression (Boolean) — default: false —

    When set to 'true' the request body will not be compressed for supported operations.

  • :endpoint (String) —

    The client endpoint is normally constructed from the :region option. You should only configure an :endpoint when connecting to test or custom endpoints. This should be a valid HTTP(S) URI.

  • :endpoint_cache_max_entries (Integer) — default: 1000 —

    Used for the maximum size limit of the LRU cache storing endpoints data for endpoint discovery enabled operations. Defaults to 1000.

  • :endpoint_cache_max_threads (Integer) — default: 10 —

    Used for the maximum threads in use for polling endpoints to be cached, defaults to 10.

  • :endpoint_cache_poll_interval (Integer) — default: 60 —

    When :endpoint_discovery and :active_endpoint_cache is enabled, Use this option to config the time interval in seconds for making requests fetching endpoints information. Defaults to 60 sec.

  • :endpoint_discovery (Boolean) — default: false —

    When set to true, endpoint discovery will be enabled for operations when available.

  • :ignore_configured_endpoint_urls (Boolean) —

    Setting to true disables use of endpoint URLs provided via environment variables and the shared configuration file.

  • :log_formatter (Aws::Log::Formatter) — default: Aws::Log::Formatter.default —

    The log formatter.

  • :log_level (Symbol) — default: :info —

    The log level to send messages to the :logger at.

  • :logger (Logger) —

    The Logger instance to send log messages to. If this option is not set, logging will be disabled.

  • :max_attempts (Integer) — default: 3 —

    An integer representing the maximum number attempts that will be made for a single request, including the initial attempt. For example, setting this value to 5 will result in a request being retried up to 4 times. Used in standard and adaptive retry modes.

  • :profile (String) — default: "default" —

    Used when loading credentials from the shared credentials file at HOME/.aws/credentials. When not specified, 'default' is used.

  • :request_min_compression_size_bytes (Integer) — default: 10240 —

    The minimum size in bytes that triggers compression for request bodies. The value must be non-negative integer value between 0 and 10485780 bytes inclusive.

  • :retry_backoff (Proc) —

    A proc or lambda used for backoff. Defaults to 2**retries * retry_base_delay. This option is only used in the legacy retry mode.

  • :retry_base_delay (Float) — default: 0.3 —

    The base delay in seconds used by the default backoff function. This option is only used in the legacy retry mode.

  • :retry_jitter (Symbol) — default: :none —

    A delay randomiser function used by the default backoff function. Some predefined functions can be referenced by name - :none, :equal, :full, otherwise a Proc that takes and returns a number. This option is only used in the legacy retry mode.

    @see https://www.awsarchitectureblog.com/2015/03/backoff.html

  • :retry_limit (Integer) — default: 3 —

    The maximum number of times to retry failed requests. Only ~ 500 level server errors and certain ~ 400 level client errors are retried. Generally, these are throttling errors, data checksum errors, networking errors, timeout errors, auth errors, endpoint discovery, and errors from expired credentials. This option is only used in the legacy retry mode.

  • :retry_max_delay (Integer) — default: 0 —

    The maximum number of seconds to delay between retries (0 for no limit) used by the default backoff function. This option is only used in the legacy retry mode.

  • :retry_mode (String) — default: "legacy" —

    Specifies which retry algorithm to use. Values are:

    • legacy - The pre-existing retry behavior. This is default value if no retry mode is provided.

    • standard - A standardized set of retry rules across the AWS SDKs. This includes support for retry quotas, which limit the number of unsuccessful retries a client can make.

    • adaptive - An experimental retry mode that includes all the functionality of standard mode along with automatic client side throttling. This is a provisional mode that may change behavior in the future.

  • :sdk_ua_app_id (String) —

    A unique and opaque application ID that is appended to the User-Agent header as app/<sdk_ua_app_id>. It should have a maximum length of 50.

  • :secret_access_key (String)
  • :session_token (String)
  • :stub_responses (Boolean) — default: false —

    Causes the client to return stubbed responses. By default fake responses are generated and returned. You can specify the response data to return or errors to raise by calling ClientStubs#stub_responses. See ClientStubs for more information.

    ** Please note ** When response stubbing is enabled, no HTTP requests are made, and retries are disabled.

  • :token_provider (Aws::TokenProvider) —

    A Bearer Token Provider. This can be an instance of any one of the following classes:

    • Aws::StaticTokenProvider - Used for configuring static, non-refreshing tokens.

    • Aws::SSOTokenProvider - Used for loading tokens from AWS SSO using an access token generated from aws login.

    When :token_provider is not configured directly, the Aws::TokenProviderChain will be used to search for tokens configured for your profile in shared configuration files.

  • :use_dualstack_endpoint (Boolean) —

    When set to true, dualstack enabled endpoints (with .aws TLD) will be used if available.

  • :use_fips_endpoint (Boolean) —

    When set to true, fips compatible endpoints will be used if available. When a fips region is used, the region is normalized and this config is set to true.

  • :validate_params (Boolean) — default: true —

    When true, request parameters are validated before sending the request.

  • :endpoint_provider (Aws::IoTRoboRunner::EndpointProvider) —

    The endpoint provider used to resolve endpoints. Any object that responds to #resolve_endpoint(parameters) where parameters is a Struct similar to Aws::IoTRoboRunner::EndpointParameters

  • :http_proxy (URI::HTTP, String) —

    A proxy to send requests through. Formatted like 'http://proxy.com:123'.

  • :http_open_timeout (Float) — default: 15 —

    The number of seconds to wait when opening a HTTP session before raising a Timeout::Error.

  • :http_read_timeout (Float) — default: 60 —

    The default number of seconds to wait for response data. This value can safely be set per-request on the session.

  • :http_idle_timeout (Float) — default: 5 —

    The number of seconds a connection is allowed to sit idle before it is considered stale. Stale connections are closed and removed from the pool before making a request.

  • :http_continue_timeout (Float) — default: 1 —

    The number of seconds to wait for a 100-continue response before sending the request body. This option has no effect unless the request has "Expect" header set to "100-continue". Defaults to nil which disables this behaviour. This value can safely be set per request on the session.

  • :ssl_timeout (Float) — default: nil —

    Sets the SSL timeout in seconds.

  • :http_wire_trace (Boolean) — default: false —

    When true, HTTP debug output will be sent to the :logger.

  • :ssl_verify_peer (Boolean) — default: true —

    When true, SSL peer certificates are verified when establishing a connection.

  • :ssl_ca_bundle (String) —

    Full path to the SSL certificate authority bundle file that should be used when verifying peer certificates. If you do not pass :ssl_ca_bundle or :ssl_ca_directory the the system default will be used if available.

  • :ssl_ca_directory (String) —

    Full path of the directory that contains the unbundled SSL certificate authority files for verifying peer certificates. If you do not pass :ssl_ca_bundle or :ssl_ca_directory the the system default will be used if available.



385
386
387
# File 'lib/aws-sdk-iotroborunner/client.rb', line 385

def initialize(*args)
  super
end

Class Attribute Details

.identifier ⇒ Object (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1326
1327
1328
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1326

def identifier
  @identifier
end

Class Method Details

.errors_module ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



1329
1330
1331
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1329

def errors_module
  Errors
end

Instance Method Details

#build_request(operation_name, params = {}) ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • params ({}) (defaults to: {})


1304
1305
1306
1307
1308
1309
1310
1311
1312
1313
1314
1315
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1304

def build_request(operation_name, params = {})
  handlers = @handlers.for(operation_name)
  context = Seahorse::Client::RequestContext.new(
    operation_name: operation_name,
    operation: config.api.operation(operation_name),
    client: self,
    params: params,
    config: config)
  context[:gem_name] = 'aws-sdk-iotroborunner'
  context[:gem_version] = '1.12.0'
  Seahorse::Client::Request.new(handlers, context)
end

#create_destination(params = {}) ⇒ Types::CreateDestinationResponse

Grants permission to create a destination

Examples:

Request syntax with placeholder values


resp = client.create_destination({
  client_token: "IdempotencyToken",
  name: "Name", # required
  site: "SiteGenericIdentifier", # required
  state: "ENABLED", # accepts ENABLED, DISABLED, DECOMMISSIONED
  additional_fixed_properties: "DestinationAdditionalFixedProperties",
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.created_at #=> Time
resp.updated_at #=> Time
resp.state #=> String, one of "ENABLED", "DISABLED", "DECOMMISSIONED"

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :client_token (String) —

    Token used for detecting replayed requests. Replayed requests will not be performed multiple times.

    A suitable default value is auto-generated. You should normally not need to pass this option.**

  • :name (required, String) —

    Human friendly name of the resource.

  • :site (required, String) —

    Site ARN.

  • :state (String) —

    The state of the destination. Default used if not specified.

  • :additional_fixed_properties (String) —

    JSON document containing additional fixed properties regarding the destination

Returns:



441
442
443
444
# File 'lib/aws-sdk-iotroborunner/client.rb', line 441

def create_destination(params = {}, options = {})
  req = build_request(:create_destination, params)
  req.send_request(options)
end

#create_site(params = {}) ⇒ Types::CreateSiteResponse

Grants permission to create a site

Examples:

Request syntax with placeholder values


resp = client.create_site({
  client_token: "IdempotencyToken",
  name: "Name", # required
  country_code: "SiteCountryCode", # required
  description: "SiteDescription",
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.created_at #=> Time
resp.updated_at #=> Time

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :client_token (String) —

    Token used for detecting replayed requests. Replayed requests will not be performed multiple times.

    A suitable default value is auto-generated. You should normally not need to pass this option.**

  • :name (required, String) —

    Human friendly name of the resource.

  • :country_code (required, String) —

    A valid ISO 3166-1 alpha-2 code for the country in which the site resides. e.g., US.

  • :description (String) —

    A high-level description of the site.

Returns:



490
491
492
493
# File 'lib/aws-sdk-iotroborunner/client.rb', line 490

def create_site(params = {}, options = {})
  req = build_request(:create_site, params)
  req.send_request(options)
end

#create_worker(params = {}) ⇒ Types::CreateWorkerResponse

Grants permission to create a worker

Examples:

Request syntax with placeholder values


resp = client.create_worker({
  client_token: "IdempotencyToken",
  name: "Name", # required
  fleet: "WorkerFleetGenericIdentifier", # required
  additional_transient_properties: "WorkerAdditionalTransientPropertiesJson",
  additional_fixed_properties: "WorkerAdditionalFixedPropertiesJson",
  vendor_properties: {
    vendor_worker_id: "VendorWorkerId", # required
    vendor_worker_ip_address: "VendorWorkerIpAddress",
    vendor_additional_transient_properties: "VendorAdditionalTransientPropertiesJson",
    vendor_additional_fixed_properties: "VendorAdditionalFixedPropertiesJson",
  },
  position: {
    cartesian_coordinates: {
      x: 1.0, # required
      y: 1.0, # required
      z: 1.0,
    },
  },
  orientation: {
    degrees: 1.0,
  },
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.created_at #=> Time
resp.updated_at #=> Time
resp.site #=> String

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :client_token (String) —

    Token used for detecting replayed requests. Replayed requests will not be performed multiple times.

    A suitable default value is auto-generated. You should normally not need to pass this option.**

  • :name (required, String) —

    Human friendly name of the resource.

  • :fleet (required, String) —

    Full ARN of the worker fleet.

  • :additional_transient_properties (String) —

    JSON blob containing unstructured worker properties that are transient and may change during regular operation.

  • :additional_fixed_properties (String) —

    JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.

  • :vendor_properties (Types::VendorProperties) —

    Properties of the worker that are provided by the vendor FMS.

  • :position (Types::PositionCoordinates) —

    Supported coordinates for worker position.

  • :orientation (Types::Orientation) —

    Worker orientation measured in units clockwise from north.

Returns:



571
572
573
574
# File 'lib/aws-sdk-iotroborunner/client.rb', line 571

def create_worker(params = {}, options = {})
  req = build_request(:create_worker, params)
  req.send_request(options)
end

#create_worker_fleet(params = {}) ⇒ Types::CreateWorkerFleetResponse

Grants permission to create a worker fleet

Examples:

Request syntax with placeholder values


resp = client.create_worker_fleet({
  client_token: "IdempotencyToken",
  name: "Name", # required
  site: "SiteGenericIdentifier", # required
  additional_fixed_properties: "WorkerFleetAdditionalFixedProperties",
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.created_at #=> Time
resp.updated_at #=> Time

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :client_token (String) —

    Token used for detecting replayed requests. Replayed requests will not be performed multiple times.

    A suitable default value is auto-generated. You should normally not need to pass this option.**

  • :name (required, String) —

    Human friendly name of the resource.

  • :site (required, String) —

    Site ARN.

  • :additional_fixed_properties (String) —

    JSON blob containing additional fixed properties regarding the worker fleet

Returns:



620
621
622
623
# File 'lib/aws-sdk-iotroborunner/client.rb', line 620

def create_worker_fleet(params = {}, options = {})
  req = build_request(:create_worker_fleet, params)
  req.send_request(options)
end

#delete_destination(params = {}) ⇒ Struct

Grants permission to delete a destination

Examples:

Request syntax with placeholder values


resp = client.delete_destination({
  id: "DestinationGenericIdentifier", # required
})

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Destination ARN.

Returns:

  • (Struct) —

    Returns an empty response.



640
641
642
643
# File 'lib/aws-sdk-iotroborunner/client.rb', line 640

def delete_destination(params = {}, options = {})
  req = build_request(:delete_destination, params)
  req.send_request(options)
end

#delete_site(params = {}) ⇒ Struct

Grants permission to delete a site

Examples:

Request syntax with placeholder values


resp = client.delete_site({
  id: "SiteGenericIdentifier", # required
})

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Site ARN.

Returns:

  • (Struct) —

    Returns an empty response.



660
661
662
663
# File 'lib/aws-sdk-iotroborunner/client.rb', line 660

def delete_site(params = {}, options = {})
  req = build_request(:delete_site, params)
  req.send_request(options)
end

#delete_worker(params = {}) ⇒ Struct

Grants permission to delete a worker

Examples:

Request syntax with placeholder values


resp = client.delete_worker({
  id: "WorkerGenericIdentifier", # required
})

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Full ARN of the worker.

Returns:

  • (Struct) —

    Returns an empty response.



680
681
682
683
# File 'lib/aws-sdk-iotroborunner/client.rb', line 680

def delete_worker(params = {}, options = {})
  req = build_request(:delete_worker, params)
  req.send_request(options)
end

#delete_worker_fleet(params = {}) ⇒ Struct

Grants permission to delete a worker fleet

Examples:

Request syntax with placeholder values


resp = client.delete_worker_fleet({
  id: "WorkerFleetGenericIdentifier", # required
})

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Full ARN of the worker fleet.

Returns:

  • (Struct) —

    Returns an empty response.



700
701
702
703
# File 'lib/aws-sdk-iotroborunner/client.rb', line 700

def delete_worker_fleet(params = {}, options = {})
  req = build_request(:delete_worker_fleet, params)
  req.send_request(options)
end

#get_destination(params = {}) ⇒ Types::GetDestinationResponse

Grants permission to get a destination

Examples:

Request syntax with placeholder values


resp = client.get_destination({
  id: "DestinationGenericIdentifier", # required
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.name #=> String
resp.site #=> String
resp.created_at #=> Time
resp.updated_at #=> Time
resp.state #=> String, one of "ENABLED", "DISABLED", "DECOMMISSIONED"
resp.additional_fixed_properties #=> String

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Destination ARN.

Returns:



740
741
742
743
# File 'lib/aws-sdk-iotroborunner/client.rb', line 740

def get_destination(params = {}, options = {})
  req = build_request(:get_destination, params)
  req.send_request(options)
end

#get_site(params = {}) ⇒ Types::GetSiteResponse

Grants permission to get a site

Examples:

Request syntax with placeholder values


resp = client.get_site({
  id: "SiteGenericIdentifier", # required
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.name #=> String
resp.country_code #=> String
resp.description #=> String
resp.created_at #=> Time
resp.updated_at #=> Time

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Site ARN.

Returns:



778
779
780
781
# File 'lib/aws-sdk-iotroborunner/client.rb', line 778

def get_site(params = {}, options = {})
  req = build_request(:get_site, params)
  req.send_request(options)
end

#get_worker(params = {}) ⇒ Types::GetWorkerResponse

Grants permission to get a worker

Examples:

Request syntax with placeholder values


resp = client.get_worker({
  id: "WorkerGenericIdentifier", # required
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.fleet #=> String
resp.site #=> String
resp.created_at #=> Time
resp.updated_at #=> Time
resp.name #=> String
resp.additional_transient_properties #=> String
resp.additional_fixed_properties #=> String
resp.vendor_properties.vendor_worker_id #=> String
resp.vendor_properties.vendor_worker_ip_address #=> String
resp.vendor_properties.vendor_additional_transient_properties #=> String
resp.vendor_properties.vendor_additional_fixed_properties #=> String
resp.position.cartesian_coordinates.x #=> Float
resp.position.cartesian_coordinates.y #=> Float
resp.position.cartesian_coordinates.z #=> Float
resp.orientation.degrees #=> Float

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Full ARN of the worker.

Returns:



831
832
833
834
# File 'lib/aws-sdk-iotroborunner/client.rb', line 831

def get_worker(params = {}, options = {})
  req = build_request(:get_worker, params)
  req.send_request(options)
end

#get_worker_fleet(params = {}) ⇒ Types::GetWorkerFleetResponse

Grants permission to get a worker fleet

Examples:

Request syntax with placeholder values


resp = client.get_worker_fleet({
  id: "WorkerFleetGenericIdentifier", # required
})

Response structure


resp.id #=> String
resp.arn #=> String
resp.name #=> String
resp.site #=> String
resp.created_at #=> Time
resp.updated_at #=> Time
resp.additional_fixed_properties #=> String

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Full ARN of the worker fleet.

Returns:



869
870
871
872
# File 'lib/aws-sdk-iotroborunner/client.rb', line 869

def get_worker_fleet(params = {}, options = {})
  req = build_request(:get_worker_fleet, params)
  req.send_request(options)
end

#list_destinations(params = {}) ⇒ Types::ListDestinationsResponse

Grants permission to list destinations

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_destinations({
  site: "SiteGenericIdentifier", # required
  max_results: 1,
  next_token: "PaginationToken",
  state: "ENABLED", # accepts ENABLED, DISABLED, DECOMMISSIONED
})

Response structure


resp.next_token #=> String
resp.destinations #=> Array
resp.destinations[0].arn #=> String
resp.destinations[0].id #=> String
resp.destinations[0].name #=> String
resp.destinations[0].site #=> String
resp.destinations[0].created_at #=> Time
resp.destinations[0].updated_at #=> Time
resp.destinations[0].state #=> String, one of "ENABLED", "DISABLED", "DECOMMISSIONED"
resp.destinations[0].additional_fixed_properties #=> String

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :site (required, String) —

    Site ARN.

  • :max_results (Integer) —

    Maximum number of results to retrieve in a single call.

  • :next_token (String) —

    Pagination token returned when another page of data exists. Provide it in your next call to the API to receive the next page.

  • :state (String) —

    State of the destination.

Returns:



920
921
922
923
# File 'lib/aws-sdk-iotroborunner/client.rb', line 920

def list_destinations(params = {}, options = {})
  req = build_request(:list_destinations, params)
  req.send_request(options)
end

#list_sites(params = {}) ⇒ Types::ListSitesResponse

Grants permission to list sites

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_sites({
  max_results: 1,
  next_token: "PaginationToken",
})

Response structure


resp.next_token #=> String
resp.sites #=> Array
resp.sites[0].arn #=> String
resp.sites[0].name #=> String
resp.sites[0].country_code #=> String
resp.sites[0].created_at #=> Time

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :max_results (Integer) —

    Maximum number of results to retrieve in a single ListSites call.

  • :next_token (String) —

    Pagination token returned when another page of data exists. Provide it in your next call to the API to receive the next page.

Returns:



959
960
961
962
# File 'lib/aws-sdk-iotroborunner/client.rb', line 959

def list_sites(params = {}, options = {})
  req = build_request(:list_sites, params)
  req.send_request(options)
end

#list_worker_fleets(params = {}) ⇒ Types::ListWorkerFleetsResponse

Grants permission to list worker fleets

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_worker_fleets({
  site: "SiteGenericIdentifier", # required
  max_results: 1,
  next_token: "PaginationToken",
})

Response structure


resp.next_token #=> String
resp.worker_fleets #=> Array
resp.worker_fleets[0].arn #=> String
resp.worker_fleets[0].id #=> String
resp.worker_fleets[0].name #=> String
resp.worker_fleets[0].site #=> String
resp.worker_fleets[0].created_at #=> Time
resp.worker_fleets[0].updated_at #=> Time
resp.worker_fleets[0].additional_fixed_properties #=> String

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :site (required, String) —

    Site ARN.

  • :max_results (Integer) —

    Maximum number of results to retrieve in a single ListWorkerFleets call.

  • :next_token (String) —

    Pagination token returned when another page of data exists. Provide it in your next call to the API to receive the next page.

Returns:



1006
1007
1008
1009
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1006

def list_worker_fleets(params = {}, options = {})
  req = build_request(:list_worker_fleets, params)
  req.send_request(options)
end

#list_workers(params = {}) ⇒ Types::ListWorkersResponse

Grants permission to list workers

The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.

Examples:

Request syntax with placeholder values


resp = client.list_workers({
  site: "SiteGenericIdentifier", # required
  max_results: 1,
  next_token: "PaginationToken",
  fleet: "WorkerFleetGenericIdentifier",
})

Response structure


resp.next_token #=> String
resp.workers #=> Array
resp.workers[0].arn #=> String
resp.workers[0].id #=> String
resp.workers[0].fleet #=> String
resp.workers[0].created_at #=> Time
resp.workers[0].updated_at #=> Time
resp.workers[0].name #=> String
resp.workers[0].site #=> String
resp.workers[0].additional_transient_properties #=> String
resp.workers[0].additional_fixed_properties #=> String
resp.workers[0].vendor_properties.vendor_worker_id #=> String
resp.workers[0].vendor_properties.vendor_worker_ip_address #=> String
resp.workers[0].vendor_properties.vendor_additional_transient_properties #=> String
resp.workers[0].vendor_properties.vendor_additional_fixed_properties #=> String
resp.workers[0].position.cartesian_coordinates.x #=> Float
resp.workers[0].position.cartesian_coordinates.y #=> Float
resp.workers[0].position.cartesian_coordinates.z #=> Float
resp.workers[0].orientation.degrees #=> Float

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :site (required, String) —

    Site ARN.

  • :max_results (Integer) —

    Maximum number of results to retrieve in a single ListWorkers call.

  • :next_token (String) —

    Pagination token returned when another page of data exists. Provide it in your next call to the API to receive the next page.

  • :fleet (String) —

    Full ARN of the worker fleet.

Returns:



1066
1067
1068
1069
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1066

def list_workers(params = {}, options = {})
  req = build_request(:list_workers, params)
  req.send_request(options)
end

#update_destination(params = {}) ⇒ Types::UpdateDestinationResponse

Grants permission to update a destination

Examples:

Request syntax with placeholder values


resp = client.update_destination({
  id: "DestinationGenericIdentifier", # required
  name: "Name",
  state: "ENABLED", # accepts ENABLED, DISABLED, DECOMMISSIONED
  additional_fixed_properties: "DestinationAdditionalFixedProperties",
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.name #=> String
resp.updated_at #=> Time
resp.state #=> String, one of "ENABLED", "DISABLED", "DECOMMISSIONED"
resp.additional_fixed_properties #=> String

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Destination ARN.

  • :name (String) —

    Human friendly name of the resource.

  • :state (String) —

    State of the destination.

  • :additional_fixed_properties (String) —

    JSON document containing additional fixed properties regarding the destination

Returns:



1115
1116
1117
1118
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1115

def update_destination(params = {}, options = {})
  req = build_request(:update_destination, params)
  req.send_request(options)
end

#update_site(params = {}) ⇒ Types::UpdateSiteResponse

Grants permission to update a site

Examples:

Request syntax with placeholder values


resp = client.update_site({
  id: "SiteGenericIdentifier", # required
  name: "Name",
  country_code: "SiteCountryCode",
  description: "SiteDescription",
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.name #=> String
resp.country_code #=> String
resp.description #=> String
resp.updated_at #=> Time

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Site ARN.

  • :name (String) —

    Human friendly name of the resource.

  • :country_code (String) —

    A valid ISO 3166-1 alpha-2 code for the country in which the site resides. e.g., US.

  • :description (String) —

    A high-level description of the site.

Returns:



1164
1165
1166
1167
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1164

def update_site(params = {}, options = {})
  req = build_request(:update_site, params)
  req.send_request(options)
end

#update_worker(params = {}) ⇒ Types::UpdateWorkerResponse

Grants permission to update a worker

Examples:

Request syntax with placeholder values


resp = client.update_worker({
  id: "WorkerGenericIdentifier", # required
  name: "Name",
  additional_transient_properties: "WorkerAdditionalTransientPropertiesJson",
  additional_fixed_properties: "WorkerAdditionalFixedPropertiesJson",
  vendor_properties: {
    vendor_worker_id: "VendorWorkerId", # required
    vendor_worker_ip_address: "VendorWorkerIpAddress",
    vendor_additional_transient_properties: "VendorAdditionalTransientPropertiesJson",
    vendor_additional_fixed_properties: "VendorAdditionalFixedPropertiesJson",
  },
  position: {
    cartesian_coordinates: {
      x: 1.0, # required
      y: 1.0, # required
      z: 1.0,
    },
  },
  orientation: {
    degrees: 1.0,
  },
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.fleet #=> String
resp.updated_at #=> Time
resp.name #=> String
resp.additional_transient_properties #=> String
resp.additional_fixed_properties #=> String
resp.orientation.degrees #=> Float
resp.vendor_properties.vendor_worker_id #=> String
resp.vendor_properties.vendor_worker_ip_address #=> String
resp.vendor_properties.vendor_additional_transient_properties #=> String
resp.vendor_properties.vendor_additional_fixed_properties #=> String
resp.position.cartesian_coordinates.x #=> Float
resp.position.cartesian_coordinates.y #=> Float
resp.position.cartesian_coordinates.z #=> Float

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Full ARN of the worker.

  • :name (String) —

    Human friendly name of the resource.

  • :additional_transient_properties (String) —

    JSON blob containing unstructured worker properties that are transient and may change during regular operation.

  • :additional_fixed_properties (String) —

    JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.

  • :vendor_properties (Types::VendorProperties) —

    Properties of the worker that are provided by the vendor FMS.

  • :position (Types::PositionCoordinates) —

    Supported coordinates for worker position.

  • :orientation (Types::Orientation) —

    Worker orientation measured in units clockwise from north.

Returns:



1252
1253
1254
1255
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1252

def update_worker(params = {}, options = {})
  req = build_request(:update_worker, params)
  req.send_request(options)
end

#update_worker_fleet(params = {}) ⇒ Types::UpdateWorkerFleetResponse

Grants permission to update a worker fleet

Examples:

Request syntax with placeholder values


resp = client.update_worker_fleet({
  id: "WorkerFleetGenericIdentifier", # required
  name: "Name",
  additional_fixed_properties: "WorkerFleetAdditionalFixedProperties",
})

Response structure


resp.arn #=> String
resp.id #=> String
resp.name #=> String
resp.updated_at #=> Time
resp.additional_fixed_properties #=> String

Parameters:

  • params (Hash) (defaults to: {}) —

    ({})

Options Hash (params):

  • :id (required, String) —

    Full ARN of the worker fleet.

  • :name (String) —

    Human friendly name of the resource.

  • :additional_fixed_properties (String) —

    JSON blob containing additional fixed properties regarding the worker fleet

Returns:



1295
1296
1297
1298
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1295

def update_worker_fleet(params = {}, options = {})
  req = build_request(:update_worker_fleet, params)
  req.send_request(options)
end

#waiter_names ⇒ Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


1319
1320
1321
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1319

def waiter_names
  []
end