Class: Aws::IoTRoboRunner::Types::CreateDestinationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotroborunner/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_fixed_properties ⇒ String

JSON document containing additional fixed properties regarding the destination

Returns:

  • (String)


82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-iotroborunner/types.rb', line 82

class CreateDestinationRequest < Struct.new(
  :client_token,
  :name,
  :site,
  :state,
  :additional_fixed_properties)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

Token used for detecting replayed requests. Replayed requests will not be performed multiple times.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-iotroborunner/types.rb', line 82

class CreateDestinationRequest < Struct.new(
  :client_token,
  :name,
  :site,
  :state,
  :additional_fixed_properties)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Human friendly name of the resource.

Returns:

  • (String)


82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-iotroborunner/types.rb', line 82

class CreateDestinationRequest < Struct.new(
  :client_token,
  :name,
  :site,
  :state,
  :additional_fixed_properties)
  SENSITIVE = []
  include Aws::Structure
end

#site ⇒ String

Site ARN.

Returns:

  • (String)


82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-iotroborunner/types.rb', line 82

class CreateDestinationRequest < Struct.new(
  :client_token,
  :name,
  :site,
  :state,
  :additional_fixed_properties)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ String

The state of the destination. Default used if not specified.

Returns:

  • (String)


82
83
84
85
86
87
88
89
90
# File 'lib/aws-sdk-iotroborunner/types.rb', line 82

class CreateDestinationRequest < Struct.new(
  :client_token,
  :name,
  :site,
  :state,
  :additional_fixed_properties)
  SENSITIVE = []
  include Aws::Structure
end