Class: Aws::IoTRoboRunner::Types::CreateSiteRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotroborunner/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

Token used for detecting replayed requests. Replayed requests will not be performed multiple times.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


143
144
145
146
147
148
149
150
# File 'lib/aws-sdk-iotroborunner/types.rb', line 143

class CreateSiteRequest < Struct.new(
  :client_token,
  :name,
  :country_code,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#country_code ⇒ String

A valid ISO 3166-1 alpha-2 code for the country in which the site resides. e.g., US.

Returns:

  • (String)


143
144
145
146
147
148
149
150
# File 'lib/aws-sdk-iotroborunner/types.rb', line 143

class CreateSiteRequest < Struct.new(
  :client_token,
  :name,
  :country_code,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

A high-level description of the site.

Returns:

  • (String)


143
144
145
146
147
148
149
150
# File 'lib/aws-sdk-iotroborunner/types.rb', line 143

class CreateSiteRequest < Struct.new(
  :client_token,
  :name,
  :country_code,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Human friendly name of the resource.

Returns:

  • (String)


143
144
145
146
147
148
149
150
# File 'lib/aws-sdk-iotroborunner/types.rb', line 143

class CreateSiteRequest < Struct.new(
  :client_token,
  :name,
  :country_code,
  :description)
  SENSITIVE = []
  include Aws::Structure
end