Class: Aws::IoTRoboRunner::Types::CreateWorkerFleetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotroborunner/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_fixed_properties ⇒ String

JSON blob containing additional fixed properties regarding the worker fleet

Returns:

  • (String)


198
199
200
201
202
203
204
205
# File 'lib/aws-sdk-iotroborunner/types.rb', line 198

class CreateWorkerFleetRequest < Struct.new(
  :client_token,
  :name,
  :site,
  :additional_fixed_properties)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

Token used for detecting replayed requests. Replayed requests will not be performed multiple times.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


198
199
200
201
202
203
204
205
# File 'lib/aws-sdk-iotroborunner/types.rb', line 198

class CreateWorkerFleetRequest < Struct.new(
  :client_token,
  :name,
  :site,
  :additional_fixed_properties)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Human friendly name of the resource.

Returns:

  • (String)


198
199
200
201
202
203
204
205
# File 'lib/aws-sdk-iotroborunner/types.rb', line 198

class CreateWorkerFleetRequest < Struct.new(
  :client_token,
  :name,
  :site,
  :additional_fixed_properties)
  SENSITIVE = []
  include Aws::Structure
end

#site ⇒ String

Site ARN.

Returns:

  • (String)


198
199
200
201
202
203
204
205
# File 'lib/aws-sdk-iotroborunner/types.rb', line 198

class CreateWorkerFleetRequest < Struct.new(
  :client_token,
  :name,
  :site,
  :additional_fixed_properties)
  SENSITIVE = []
  include Aws::Structure
end