Class: Aws::IoTRoboRunner::Types::CreateWorkerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::CreateWorkerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_fixed_properties ⇒ String
JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.
-
#additional_transient_properties ⇒ String
JSON blob containing unstructured worker properties that are transient and may change during regular operation.
-
#client_token ⇒ String
Token used for detecting replayed requests.
-
#fleet ⇒ String
Full ARN of the worker fleet.
-
#name ⇒ String
Human friendly name of the resource.
-
#orientation ⇒ Types::Orientation
Worker orientation measured in units clockwise from north.
-
#position ⇒ Types::PositionCoordinates
Supported coordinates for worker position.
-
#vendor_properties ⇒ Types::VendorProperties
Properties of the worker that are provided by the vendor FMS.
Instance Attribute Details
#additional_fixed_properties ⇒ String
JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 270 class CreateWorkerRequest < Struct.new( :client_token, :name, :fleet, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#additional_transient_properties ⇒ String
JSON blob containing unstructured worker properties that are transient and may change during regular operation.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 270 class CreateWorkerRequest < Struct.new( :client_token, :name, :fleet, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Token used for detecting replayed requests. Replayed requests will not be performed multiple times.
A suitable default value is auto-generated. You should normally not need to pass this option.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 270 class CreateWorkerRequest < Struct.new( :client_token, :name, :fleet, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#fleet ⇒ String
Full ARN of the worker fleet.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 270 class CreateWorkerRequest < Struct.new( :client_token, :name, :fleet, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 270 class CreateWorkerRequest < Struct.new( :client_token, :name, :fleet, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#orientation ⇒ Types::Orientation
Worker orientation measured in units clockwise from north.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 270 class CreateWorkerRequest < Struct.new( :client_token, :name, :fleet, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#position ⇒ Types::PositionCoordinates
Supported coordinates for worker position.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 270 class CreateWorkerRequest < Struct.new( :client_token, :name, :fleet, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#vendor_properties ⇒ Types::VendorProperties
Properties of the worker that are provided by the vendor FMS.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 270 class CreateWorkerRequest < Struct.new( :client_token, :name, :fleet, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |