Class: Aws::IoTRoboRunner::Types::GetDestinationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::GetDestinationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_fixed_properties ⇒ String
JSON document containing additional fixed properties regarding the destination.
-
#arn ⇒ String
Destination ARN.
-
#created_at ⇒ Time
Timestamp at which the resource was created.
-
#id ⇒ String
Filters access by the destination's identifier.
-
#name ⇒ String
Human friendly name of the resource.
-
#site ⇒ String
Site ARN.
-
#state ⇒ String
State of the destination.
-
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
Instance Attribute Details
#additional_fixed_properties ⇒ String
JSON document containing additional fixed properties regarding the destination
452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 452 class GetDestinationResponse < Struct.new( :arn, :id, :name, :site, :created_at, :updated_at, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
Destination ARN.
452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 452 class GetDestinationResponse < Struct.new( :arn, :id, :name, :site, :created_at, :updated_at, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp at which the resource was created.
452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 452 class GetDestinationResponse < Struct.new( :arn, :id, :name, :site, :created_at, :updated_at, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Filters access by the destination's identifier
452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 452 class GetDestinationResponse < Struct.new( :arn, :id, :name, :site, :created_at, :updated_at, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 452 class GetDestinationResponse < Struct.new( :arn, :id, :name, :site, :created_at, :updated_at, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#site ⇒ String
Site ARN.
452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 452 class GetDestinationResponse < Struct.new( :arn, :id, :name, :site, :created_at, :updated_at, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
State of the destination.
452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 452 class GetDestinationResponse < Struct.new( :arn, :id, :name, :site, :created_at, :updated_at, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 452 class GetDestinationResponse < Struct.new( :arn, :id, :name, :site, :created_at, :updated_at, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |