Class: Aws::IoTRoboRunner::Types::GetWorkerFleetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::GetWorkerFleetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_fixed_properties ⇒ String
JSON blob containing additional fixed properties regarding the worker fleet.
-
#arn ⇒ String
Full ARN of the worker fleet.
-
#created_at ⇒ Time
Timestamp at which the resource was created.
-
#id ⇒ String
Filters access by the worker fleet's identifier.
-
#name ⇒ String
Human friendly name of the resource.
-
#site ⇒ String
Site ARN.
-
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
Instance Attribute Details
#additional_fixed_properties ⇒ String
JSON blob containing additional fixed properties regarding the worker fleet
555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 555 class GetWorkerFleetResponse < Struct.new( :id, :arn, :name, :site, :created_at, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
Full ARN of the worker fleet.
555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 555 class GetWorkerFleetResponse < Struct.new( :id, :arn, :name, :site, :created_at, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp at which the resource was created.
555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 555 class GetWorkerFleetResponse < Struct.new( :id, :arn, :name, :site, :created_at, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Filters access by the worker fleet's identifier
555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 555 class GetWorkerFleetResponse < Struct.new( :id, :arn, :name, :site, :created_at, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 555 class GetWorkerFleetResponse < Struct.new( :id, :arn, :name, :site, :created_at, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#site ⇒ String
Site ARN.
555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 555 class GetWorkerFleetResponse < Struct.new( :id, :arn, :name, :site, :created_at, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 555 class GetWorkerFleetResponse < Struct.new( :id, :arn, :name, :site, :created_at, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |