Class: Aws::IoTRoboRunner::Types::GetWorkerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::GetWorkerResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_fixed_properties ⇒ String
JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.
-
#additional_transient_properties ⇒ String
JSON blob containing unstructured worker properties that are transient and may change during regular operation.
-
#arn ⇒ String
Full ARN of the worker.
-
#created_at ⇒ Time
Timestamp at which the resource was created.
-
#fleet ⇒ String
Full ARN of the worker fleet.
-
#id ⇒ String
Filters access by the workers identifier.
-
#name ⇒ String
Human friendly name of the resource.
-
#orientation ⇒ Types::Orientation
Worker orientation measured in units clockwise from north.
-
#position ⇒ Types::PositionCoordinates
Supported coordinates for worker position.
-
#site ⇒ String
Site ARN.
-
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
-
#vendor_properties ⇒ Types::VendorProperties
Properties of the worker that are provided by the vendor FMS.
Instance Attribute Details
#additional_fixed_properties ⇒ String
JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#additional_transient_properties ⇒ String
JSON blob containing unstructured worker properties that are transient and may change during regular operation.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
Full ARN of the worker.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
Timestamp at which the resource was created.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#fleet ⇒ String
Full ARN of the worker fleet.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Filters access by the workers identifier
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#orientation ⇒ Types::Orientation
Worker orientation measured in units clockwise from north.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#position ⇒ Types::PositionCoordinates
Supported coordinates for worker position.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#site ⇒ String
Site ARN.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#vendor_properties ⇒ Types::VendorProperties
Properties of the worker that are provided by the vendor FMS.
627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 627 class GetWorkerResponse < Struct.new( :arn, :id, :fleet, :site, :created_at, :updated_at, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |