Class: Aws::IoTRoboRunner::Types::Site

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotroborunner/types.rb

Overview

Facility containing destinations, workers, activities, and tasks.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

Site ARN.

Returns:

  • (String)


895
896
897
898
899
900
901
902
# File 'lib/aws-sdk-iotroborunner/types.rb', line 895

class Site < Struct.new(
  :arn,
  :name,
  :country_code,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#country_code ⇒ String

A valid ISO 3166-1 alpha-2 code for the country in which the site resides. e.g., US.

Returns:

  • (String)


895
896
897
898
899
900
901
902
# File 'lib/aws-sdk-iotroborunner/types.rb', line 895

class Site < Struct.new(
  :arn,
  :name,
  :country_code,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

Timestamp at which the resource was created.

Returns:

  • (Time)


895
896
897
898
899
900
901
902
# File 'lib/aws-sdk-iotroborunner/types.rb', line 895

class Site < Struct.new(
  :arn,
  :name,
  :country_code,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the site. Mutable after creation and unique within a given account.

Returns:

  • (String)


895
896
897
898
899
900
901
902
# File 'lib/aws-sdk-iotroborunner/types.rb', line 895

class Site < Struct.new(
  :arn,
  :name,
  :country_code,
  :created_at)
  SENSITIVE = []
  include Aws::Structure
end