Class: Aws::IoTRoboRunner::Types::UpdateDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::UpdateDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_fixed_properties ⇒ String
JSON document containing additional fixed properties regarding the destination.
-
#id ⇒ String
Destination ARN.
-
#name ⇒ String
Human friendly name of the resource.
-
#state ⇒ String
State of the destination.
Instance Attribute Details
#additional_fixed_properties ⇒ String
JSON document containing additional fixed properties regarding the destination
932 933 934 935 936 937 938 939 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 932 class UpdateDestinationRequest < Struct.new( :id, :name, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Destination ARN.
932 933 934 935 936 937 938 939 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 932 class UpdateDestinationRequest < Struct.new( :id, :name, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
932 933 934 935 936 937 938 939 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 932 class UpdateDestinationRequest < Struct.new( :id, :name, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
State of the destination.
932 933 934 935 936 937 938 939 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 932 class UpdateDestinationRequest < Struct.new( :id, :name, :state, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |