Class: Aws::IoTRoboRunner::Types::UpdateSiteRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::UpdateSiteRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#country_code ⇒ String
A valid ISO 3166-1 alpha-2 code for the country in which the site resides.
-
#description ⇒ String
A high-level description of the site.
-
#id ⇒ String
Site ARN.
-
#name ⇒ String
Human friendly name of the resource.
Instance Attribute Details
#country_code ⇒ String
A valid ISO 3166-1 alpha-2 code for the country in which the site resides. e.g., US.
994 995 996 997 998 999 1000 1001 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 994 class UpdateSiteRequest < Struct.new( :id, :name, :country_code, :description) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A high-level description of the site.
994 995 996 997 998 999 1000 1001 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 994 class UpdateSiteRequest < Struct.new( :id, :name, :country_code, :description) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Site ARN.
994 995 996 997 998 999 1000 1001 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 994 class UpdateSiteRequest < Struct.new( :id, :name, :country_code, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
994 995 996 997 998 999 1000 1001 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 994 class UpdateSiteRequest < Struct.new( :id, :name, :country_code, :description) SENSITIVE = [] include Aws::Structure end |