Class: Aws::IoTRoboRunner::Types::UpdateSiteResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::UpdateSiteResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Site ARN.
-
#country_code ⇒ String
A valid ISO 3166-1 alpha-2 code for the country in which the site resides.
-
#description ⇒ String
A high-level description of the site.
-
#id ⇒ String
Filters access by the site's identifier.
-
#name ⇒ String
Human friendly name of the resource.
-
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
Instance Attribute Details
#arn ⇒ String
Site ARN.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1028 class UpdateSiteResponse < Struct.new( :arn, :id, :name, :country_code, :description, :updated_at) SENSITIVE = [] include Aws::Structure end |
#country_code ⇒ String
A valid ISO 3166-1 alpha-2 code for the country in which the site resides. e.g., US.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1028 class UpdateSiteResponse < Struct.new( :arn, :id, :name, :country_code, :description, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A high-level description of the site.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1028 class UpdateSiteResponse < Struct.new( :arn, :id, :name, :country_code, :description, :updated_at) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Filters access by the site's identifier
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1028 class UpdateSiteResponse < Struct.new( :arn, :id, :name, :country_code, :description, :updated_at) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1028 class UpdateSiteResponse < Struct.new( :arn, :id, :name, :country_code, :description, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1028 class UpdateSiteResponse < Struct.new( :arn, :id, :name, :country_code, :description, :updated_at) SENSITIVE = [] include Aws::Structure end |