Class: Aws::IoTRoboRunner::Types::UpdateWorkerFleetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::UpdateWorkerFleetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_fixed_properties ⇒ String
JSON blob containing additional fixed properties regarding the worker fleet.
-
#id ⇒ String
Full ARN of the worker fleet.
-
#name ⇒ String
Human friendly name of the resource.
Instance Attribute Details
#additional_fixed_properties ⇒ String
JSON blob containing additional fixed properties regarding the worker fleet
1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1052 class UpdateWorkerFleetRequest < Struct.new( :id, :name, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Full ARN of the worker fleet.
1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1052 class UpdateWorkerFleetRequest < Struct.new( :id, :name, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
1052 1053 1054 1055 1056 1057 1058 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1052 class UpdateWorkerFleetRequest < Struct.new( :id, :name, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |