Class: Aws::IoTRoboRunner::Types::UpdateWorkerFleetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::UpdateWorkerFleetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_fixed_properties ⇒ String
JSON blob containing additional fixed properties regarding the worker fleet.
-
#arn ⇒ String
Full ARN of the worker fleet.
-
#id ⇒ String
Filters access by the worker fleet's identifier.
-
#name ⇒ String
Human friendly name of the resource.
-
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
Instance Attribute Details
#additional_fixed_properties ⇒ String
JSON blob containing additional fixed properties regarding the worker fleet
1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1081 class UpdateWorkerFleetResponse < Struct.new( :arn, :id, :name, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
Full ARN of the worker fleet.
1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1081 class UpdateWorkerFleetResponse < Struct.new( :arn, :id, :name, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Filters access by the worker fleet's identifier
1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1081 class UpdateWorkerFleetResponse < Struct.new( :arn, :id, :name, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1081 class UpdateWorkerFleetResponse < Struct.new( :arn, :id, :name, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
Timestamp at which the resource was last updated.
1081 1082 1083 1084 1085 1086 1087 1088 1089 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1081 class UpdateWorkerFleetResponse < Struct.new( :arn, :id, :name, :updated_at, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |