Class: Aws::IoTRoboRunner::Types::UpdateWorkerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::UpdateWorkerRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_fixed_properties ⇒ String
JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.
-
#additional_transient_properties ⇒ String
JSON blob containing unstructured worker properties that are transient and may change during regular operation.
-
#id ⇒ String
Full ARN of the worker.
-
#name ⇒ String
Human friendly name of the resource.
-
#orientation ⇒ Types::Orientation
Worker orientation measured in units clockwise from north.
-
#position ⇒ Types::PositionCoordinates
Supported coordinates for worker position.
-
#vendor_properties ⇒ Types::VendorProperties
Properties of the worker that are provided by the vendor FMS.
Instance Attribute Details
#additional_fixed_properties ⇒ String
JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.
1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1121 class UpdateWorkerRequest < Struct.new( :id, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#additional_transient_properties ⇒ String
JSON blob containing unstructured worker properties that are transient and may change during regular operation.
1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1121 class UpdateWorkerRequest < Struct.new( :id, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
Full ARN of the worker.
1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1121 class UpdateWorkerRequest < Struct.new( :id, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1121 class UpdateWorkerRequest < Struct.new( :id, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#orientation ⇒ Types::Orientation
Worker orientation measured in units clockwise from north.
1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1121 class UpdateWorkerRequest < Struct.new( :id, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#position ⇒ Types::PositionCoordinates
Supported coordinates for worker position.
1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1121 class UpdateWorkerRequest < Struct.new( :id, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |
#vendor_properties ⇒ Types::VendorProperties
Properties of the worker that are provided by the vendor FMS.
1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1121 class UpdateWorkerRequest < Struct.new( :id, :name, :additional_transient_properties, :additional_fixed_properties, :vendor_properties, :position, :orientation) SENSITIVE = [] include Aws::Structure end |