Class: Aws::IoTRoboRunner::Types::UpdateWorkerResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotroborunner/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_fixed_properties ⇒ String

JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.

Returns:

  • (String)


1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#additional_transient_properties ⇒ String

JSON blob containing unstructured worker properties that are transient and may change during regular operation.

Returns:

  • (String)


1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#arn ⇒ String

Full ARN of the worker.

Returns:

  • (String)


1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#fleet ⇒ String

Full ARN of the worker fleet.

Returns:

  • (String)


1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

Filters access by the workers identifier

Returns:

  • (String)


1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Human friendly name of the resource.

Returns:

  • (String)


1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#orientation ⇒ Types::Orientation

Worker orientation measured in units clockwise from north.

Returns:



1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#position ⇒ Types::PositionCoordinates

Supported coordinates for worker position.



1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

Timestamp at which the resource was last updated.

Returns:

  • (Time)


1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_properties ⇒ Types::VendorProperties

Properties of the worker that are provided by the vendor FMS.



1175
1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
1187
1188
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1175

class UpdateWorkerResponse < Struct.new(
  :arn,
  :id,
  :fleet,
  :updated_at,
  :name,
  :additional_transient_properties,
  :additional_fixed_properties,
  :orientation,
  :vendor_properties,
  :position)
  SENSITIVE = []
  include Aws::Structure
end