Class: Aws::IoTRoboRunner::Types::Worker

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotroborunner/types.rb

Overview

A unit capable of performing tasks.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_fixed_properties ⇒ String

JSON blob containing unstructured worker properties that are fixed and won't change during regular operation.

Returns:

  • (String)


1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#additional_transient_properties ⇒ String

JSON blob containing unstructured worker properties that are transient and may change during regular operation.

Returns:

  • (String)


1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#arn ⇒ String

Full ARN of the worker.

Returns:

  • (String)


1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

Timestamp at which the resource was created.

Returns:

  • (Time)


1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#fleet ⇒ String

Full ARN of the worker fleet.

Returns:

  • (String)


1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

Filters access by the workers identifier

Returns:

  • (String)


1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Human friendly name of the resource.

Returns:

  • (String)


1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#orientation ⇒ Types::Orientation

Worker orientation measured in units clockwise from north.

Returns:



1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#position ⇒ Types::PositionCoordinates

Supported coordinates for worker position.



1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#site ⇒ String

Site ARN.

Returns:

  • (String)


1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#updated_at ⇒ Time

Timestamp at which the resource was last updated.

Returns:

  • (Time)


1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_properties ⇒ Types::VendorProperties

Properties of the worker that are provided by the vendor FMS.



1282
1283
1284
1285
1286
1287
1288
1289
1290
1291
1292
1293
1294
1295
1296
1297
# File 'lib/aws-sdk-iotroborunner/types.rb', line 1282

class Worker < Struct.new(
  :arn,
  :id,
  :fleet,
  :created_at,
  :updated_at,
  :name,
  :site,
  :additional_transient_properties,
  :additional_fixed_properties,
  :vendor_properties,
  :position,
  :orientation)
  SENSITIVE = []
  include Aws::Structure
end