Class: Aws::IoTRoboRunner::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTRoboRunner::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotroborunner/client.rb
Overview
An API client for IoTRoboRunner. To construct a client, you need to configure a :region and :credentials.
client = Aws::IoTRoboRunner::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_destination(params = {}) ⇒ Types::CreateDestinationResponse
Grants permission to create a destination.
-
#create_site(params = {}) ⇒ Types::CreateSiteResponse
Grants permission to create a site.
-
#create_worker(params = {}) ⇒ Types::CreateWorkerResponse
Grants permission to create a worker.
-
#create_worker_fleet(params = {}) ⇒ Types::CreateWorkerFleetResponse
Grants permission to create a worker fleet.
-
#delete_destination(params = {}) ⇒ Struct
Grants permission to delete a destination.
-
#delete_site(params = {}) ⇒ Struct
Grants permission to delete a site.
-
#delete_worker(params = {}) ⇒ Struct
Grants permission to delete a worker.
-
#delete_worker_fleet(params = {}) ⇒ Struct
Grants permission to delete a worker fleet.
-
#get_destination(params = {}) ⇒ Types::GetDestinationResponse
Grants permission to get a destination.
-
#get_site(params = {}) ⇒ Types::GetSiteResponse
Grants permission to get a site.
-
#get_worker(params = {}) ⇒ Types::GetWorkerResponse
Grants permission to get a worker.
-
#get_worker_fleet(params = {}) ⇒ Types::GetWorkerFleetResponse
Grants permission to get a worker fleet.
-
#list_destinations(params = {}) ⇒ Types::ListDestinationsResponse
Grants permission to list destinations.
-
#list_sites(params = {}) ⇒ Types::ListSitesResponse
Grants permission to list sites.
-
#list_worker_fleets(params = {}) ⇒ Types::ListWorkerFleetsResponse
Grants permission to list worker fleets.
-
#list_workers(params = {}) ⇒ Types::ListWorkersResponse
Grants permission to list workers.
-
#update_destination(params = {}) ⇒ Types::UpdateDestinationResponse
Grants permission to update a destination.
-
#update_site(params = {}) ⇒ Types::UpdateSiteResponse
Grants permission to update a site.
-
#update_worker(params = {}) ⇒ Types::UpdateWorkerResponse
Grants permission to update a worker.
-
#update_worker_fleet(params = {}) ⇒ Types::UpdateWorkerFleetResponse
Grants permission to update a worker fleet.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
385 386 387 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 385 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1326 1327 1328 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1326 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1329 1330 1331 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1329 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1304 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-iotroborunner' context[:gem_version] = '1.12.0' Seahorse::Client::Request.new(handlers, context) end |
#create_destination(params = {}) ⇒ Types::CreateDestinationResponse
Grants permission to create a destination
441 442 443 444 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 441 def create_destination(params = {}, = {}) req = build_request(:create_destination, params) req.send_request() end |
#create_site(params = {}) ⇒ Types::CreateSiteResponse
Grants permission to create a site
490 491 492 493 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 490 def create_site(params = {}, = {}) req = build_request(:create_site, params) req.send_request() end |
#create_worker(params = {}) ⇒ Types::CreateWorkerResponse
Grants permission to create a worker
571 572 573 574 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 571 def create_worker(params = {}, = {}) req = build_request(:create_worker, params) req.send_request() end |
#create_worker_fleet(params = {}) ⇒ Types::CreateWorkerFleetResponse
Grants permission to create a worker fleet
620 621 622 623 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 620 def create_worker_fleet(params = {}, = {}) req = build_request(:create_worker_fleet, params) req.send_request() end |
#delete_destination(params = {}) ⇒ Struct
Grants permission to delete a destination
640 641 642 643 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 640 def delete_destination(params = {}, = {}) req = build_request(:delete_destination, params) req.send_request() end |
#delete_site(params = {}) ⇒ Struct
Grants permission to delete a site
660 661 662 663 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 660 def delete_site(params = {}, = {}) req = build_request(:delete_site, params) req.send_request() end |
#delete_worker(params = {}) ⇒ Struct
Grants permission to delete a worker
680 681 682 683 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 680 def delete_worker(params = {}, = {}) req = build_request(:delete_worker, params) req.send_request() end |
#delete_worker_fleet(params = {}) ⇒ Struct
Grants permission to delete a worker fleet
700 701 702 703 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 700 def delete_worker_fleet(params = {}, = {}) req = build_request(:delete_worker_fleet, params) req.send_request() end |
#get_destination(params = {}) ⇒ Types::GetDestinationResponse
Grants permission to get a destination
740 741 742 743 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 740 def get_destination(params = {}, = {}) req = build_request(:get_destination, params) req.send_request() end |
#get_site(params = {}) ⇒ Types::GetSiteResponse
Grants permission to get a site
778 779 780 781 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 778 def get_site(params = {}, = {}) req = build_request(:get_site, params) req.send_request() end |
#get_worker(params = {}) ⇒ Types::GetWorkerResponse
Grants permission to get a worker
831 832 833 834 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 831 def get_worker(params = {}, = {}) req = build_request(:get_worker, params) req.send_request() end |
#get_worker_fleet(params = {}) ⇒ Types::GetWorkerFleetResponse
Grants permission to get a worker fleet
869 870 871 872 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 869 def get_worker_fleet(params = {}, = {}) req = build_request(:get_worker_fleet, params) req.send_request() end |
#list_destinations(params = {}) ⇒ Types::ListDestinationsResponse
Grants permission to list destinations
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
920 921 922 923 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 920 def list_destinations(params = {}, = {}) req = build_request(:list_destinations, params) req.send_request() end |
#list_sites(params = {}) ⇒ Types::ListSitesResponse
Grants permission to list sites
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
959 960 961 962 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 959 def list_sites(params = {}, = {}) req = build_request(:list_sites, params) req.send_request() end |
#list_worker_fleets(params = {}) ⇒ Types::ListWorkerFleetsResponse
Grants permission to list worker fleets
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1006 1007 1008 1009 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1006 def list_worker_fleets(params = {}, = {}) req = build_request(:list_worker_fleets, params) req.send_request() end |
#list_workers(params = {}) ⇒ Types::ListWorkersResponse
Grants permission to list workers
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1066 1067 1068 1069 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1066 def list_workers(params = {}, = {}) req = build_request(:list_workers, params) req.send_request() end |
#update_destination(params = {}) ⇒ Types::UpdateDestinationResponse
Grants permission to update a destination
1115 1116 1117 1118 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1115 def update_destination(params = {}, = {}) req = build_request(:update_destination, params) req.send_request() end |
#update_site(params = {}) ⇒ Types::UpdateSiteResponse
Grants permission to update a site
1164 1165 1166 1167 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1164 def update_site(params = {}, = {}) req = build_request(:update_site, params) req.send_request() end |
#update_worker(params = {}) ⇒ Types::UpdateWorkerResponse
Grants permission to update a worker
1252 1253 1254 1255 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1252 def update_worker(params = {}, = {}) req = build_request(:update_worker, params) req.send_request() end |
#update_worker_fleet(params = {}) ⇒ Types::UpdateWorkerFleetResponse
Grants permission to update a worker fleet
1295 1296 1297 1298 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1295 def update_worker_fleet(params = {}, = {}) req = build_request(:update_worker_fleet, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1319 1320 1321 |
# File 'lib/aws-sdk-iotroborunner/client.rb', line 1319 def waiter_names [] end |