Class: Aws::IoTRoboRunner::Types::CreateWorkerFleetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTRoboRunner::Types::CreateWorkerFleetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotroborunner/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_fixed_properties ⇒ String
JSON blob containing additional fixed properties regarding the worker fleet.
-
#client_token ⇒ String
Token used for detecting replayed requests.
-
#name ⇒ String
Human friendly name of the resource.
-
#site ⇒ String
Site ARN.
Instance Attribute Details
#additional_fixed_properties ⇒ String
JSON blob containing additional fixed properties regarding the worker fleet
198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 198 class CreateWorkerFleetRequest < Struct.new( :client_token, :name, :site, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Token used for detecting replayed requests. Replayed requests will not be performed multiple times.
A suitable default value is auto-generated. You should normally not need to pass this option.
198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 198 class CreateWorkerFleetRequest < Struct.new( :client_token, :name, :site, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Human friendly name of the resource.
198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 198 class CreateWorkerFleetRequest < Struct.new( :client_token, :name, :site, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |
#site ⇒ String
Site ARN.
198 199 200 201 202 203 204 205 |
# File 'lib/aws-sdk-iotroborunner/types.rb', line 198 class CreateWorkerFleetRequest < Struct.new( :client_token, :name, :site, :additional_fixed_properties) SENSITIVE = [] include Aws::Structure end |